# Installation

You can easily install Fronty using pip. Just run the following command in your terminal.

```bash
pip install fronty
```

You can also install a backend framework to use with Fronty. For example, if you want to use Fronty with Flask, you can checkout flask documentation [https://flask.palletsprojects.com/en/2.1.x/installation/](https://flask.palletsprojects.com/en/2.1.x/installation/){:target="_blank"}

If you want to use Fronty with Django, you can checkout django documentation [https://docs.djangoproject.com/en/4.2/topics/install/](https://docs.djangoproject.com/en/4.2/topics/install/){:target="_blank"}

If you want to use Fronty with FastAPI, you can checkout fastapi documentation [https://fastapi.tiangolo.com/tutorial/first-steps/](https://fastapi.tiangolo.com/tutorial/first-steps/){:target="_blank"}

--- 

Start learning Fronty by reading the [documentation][docs].

Want to contribute? Check out the [Github project][github].

[almas]: https://github.com/Almas-Ali "Md. Almas Ali"
[github]: https://github.com/Almas-Ali/Fronty "Fronty"
[docs]: https://almas-ali.github.io/fronty/ "Docs"
[pypi]: https://pypi.org/project/fronty/ "Pypi"
